//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2008 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#include "Filterflip.h"

#include <cstring>

namespace avg {

FilterFlip::FilterFlip() : Filter()
{
}

FilterFlip::~FilterFlip()
{
}

BitmapPtr FilterFlip::apply(BitmapPtr pBmpSource) 
{
    IntPoint size = pBmpSource->getSize();
    BitmapPtr pBmpDest(new Bitmap(size, pBmpSource->getPixelFormat(), 
            pBmpSource->getName()));

    unsigned char* pSrcLine = pBmpSource->getPixels();
    unsigned char* pDestLine = pBmpDest->getPixels()+(size.y-1)*pBmpDest->getStride();
    int lineLen = pBmpSource->getBytesPerPixel()*size.x;

    for (int y = 0; y < size.y; y++) {
        memcpy(pDestLine, pSrcLine, lineLen);
        pSrcLine += pBmpSource->getStride();
        pDestLine -= pBmpDest->getStride();
    }
    return pBmpDest;
}

} // namespace
